@@ -7,9 +7,9 @@
 .. moduleauthor:: Vilmos Nebehaj
 """
 
-from iptc.ip4tc import (is_table_available, Table, Chain, Rule, Match, Target,
-                   Policy, IPTCError)
+from iptc.ip4tc import (is_table_available, Table, Chain, Rule, Match, Target, Policy, IPTCError)
 from iptc.ip6tc import is_table6_available, Table6, Rule6
-from iptc.xtables import XTablesError
+from iptc.errors import *
+
 
 __all__ = []
