@@ -102,7 +102,7 @@ class ipt_entry(ct.Structure):
 class IPTCError(Exception):
     """This exception is raised when a low-level libiptc error occurs.
 
-    It contains a short description about the error that occured while
+    It contains a short description about the error that occurred while
     executing an iptables operation.
     """
 
@@ -1400,10 +1400,11 @@ class Chain(object):
     _cache = weakref.WeakValueDictionary()
 
     def __new__(cls, table, name):
-        obj = Chain._cache.get(table.name + "." + name, None)
+        table_name = type(table).__name__ + "." + table.name
+        obj = Chain._cache.get(table_name + "." + name, None)
         if not obj:
             obj = object.__new__(cls)
-            Chain._cache[table.name + "." + name] = obj
+            Chain._cache[table_name + "." + name] = obj
         return obj
 
     def __init__(self, table, name):
@@ -1552,7 +1553,9 @@ class Table(object):
     """This is the constant for the raw table."""
     NAT = "nat"
     """This is the constant for the nat table."""
-    ALL = ["filter", "mangle", "raw", "nat"]
+    SECURITY = "security"
+    """This is the constant for the security table."""
+    ALL = ["filter", "mangle", "raw", "nat", "security"]
     """This is the constant for all tables."""
 
     _cache = dict()
@@ -1714,7 +1717,7 @@ class Table(object):
         rv = self._iptc.iptc_set_policy(chain.encode(), policy.encode(),
                                         cntrs, self._handle)
         if rv != 1:
-            raise IPTCError("can't set policy %s on chain %s: %s)" %
+            raise IPTCError("can't set policy %s on chain %s: %s" %
                             (policy, chain, self.strerror()))
 
     @autocommit
@@ -1739,7 +1742,7 @@ class Table(object):
                                           ct.cast(entry, ct.c_void_p),
                                           self._handle)
         if rv != 1:
-            raise IPTCError("can't append entry to chain %s: %s)" %
+            raise IPTCError("can't append entry to chain %s: %s" %
                             (chain, self.strerror()))
 
     @autocommit
@@ -1749,7 +1752,7 @@ class Table(object):
                                           ct.cast(entry, ct.c_void_p),
                                           position, self._handle)
         if rv != 1:
-            raise IPTCError("can't insert entry into chain %s: %s)" %
+            raise IPTCError("can't insert entry into chain %s: %s" %
                             (chain, self.strerror()))
 
     @autocommit
@@ -1759,7 +1762,7 @@ class Table(object):
                                            ct.cast(entry, ct.c_void_p),
                                            position, self._handle)
         if rv != 1:
-            raise IPTCError("can't replace entry in chain %s: %s)" %
+            raise IPTCError("can't replace entry in chain %s: %s" %
                             (chain, self.strerror()))
 
     @autocommit
@@ -1769,7 +1772,7 @@ class Table(object):
                                           ct.cast(entry, ct.c_void_p),
                                           mask, self._handle)
         if rv != 1:
-            raise IPTCError("can't delete entry from chain %s: %s)" %
+            raise IPTCError("can't delete entry from chain %s: %s" %
                             (chain, self.strerror()))
 
     def first_rule(self, chain):
